  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.2307/20650295', citation: "Angst, & Agarwal. (2009). Adoption of Electronic Health Records in the Presence of Privacy Concerns: The Elaboration Likelihood Model and Individual Persuasion. MIS Quarterly, 33(2), 339."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Argument frame', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Issue involvement', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Ability', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Pre-attitude', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Post-attitude', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Opt-in intention', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Concern for information privacy', elementType: 'Construct'});

  // Create definitions of constructs and concepts
  CREATE (:Definition {DefinitionName: 'Argument frame', definition:"Argument framing refers to the extent to which the message highlights the consequences of a behavior and infers causality"});
  CREATE (:Definition {DefinitionName: 'Issue involvement', definition:"the extent to which recipients perceive a message topic to be personally important or relevant"});
  CREATE (:Definition {DefinitionName: 'Opt-in intention', definition:"the extent to which the individual would agree to have his/her medical information digitized and shared with relevant parties"});
  CREATE (:Definition {DefinitionName: 'Ability', definition:"the cognitive capability of a recipient to process a very simple message"});
  CREATE (:Definition {DefinitionName: 'Concern for information privacy', definition:"measure attitudes and beliefs about individual information privacy related to the use of personal information in a business setting. They conceptualized CFIP as being composed of four distinct, yet correlated latent factors, labeled collection, errors, unauthorized access, and secondary use."});

  // Create a relationships between a publication and definitions it contains
  MATCH (p:Publication {DOI: '10.2307/20650295'}), (a:Definition {DefinitionName: 'Issue involvement'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/20650295'}), (a:Definition {DefinitionName: 'Argument frame'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/20650295'}), (a:Definition {DefinitionName: 'Opt-in intention'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/20650295'}), (a:Definition {DefinitionName: 'Ability'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/20650295'}), (a:Definition {DefinitionName: 'Concern for information privacy'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;

  // Create relationships between definitions and constructs
  MATCH (a:Element {elementName: 'Issue involvement'}), (b:Definition {DefinitionName: 'Issue involvement'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Argument frame'}), (b:Definition {DefinitionName: 'Argument frame'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Opt-in intention'}), (b:Definition {DefinitionName: 'Opt-in intention'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Ability'}), (b:Definition {DefinitionName: 'Ability'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Concern for information privacy'}), (b:Definition {DefinitionName: 'Concern for information privacy'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;


  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='0cbda5b9-d348-4813-a5e3-4f3a778896b9';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.2307/20650295"}),(g:Model)
  WHERE g.id IN ['0cbda5b9-d348-4813-a5e3-4f3a778896b9']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: '0cbda5b9-d348-4813-a5e3-4f3a778896b9'}),(e:Element)
  WHERE e.elementName IN ['Argument frame', 'Issue involvement', 'Ability', 'Pre-attitude', 'Post-attitude', 'Opt-in intention','Concern for information privacy']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Argument frame'}),(b:Element {elementName: 'Post-attitude'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Issue involvement'}),(b:Element {elementName: 'Post-attitude'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName:  "Argument frame"}),(b:Element {elementName:  "Issue involvement"}),(c:Element {elementName: "Post-attitude"})
  CREATE (a)-[r1:RELATES_TO {type: 'moderates' , model: 'Research model'}]->(b)-[r2:RELATES_TO {type: 'moderates', model: 'Research model'}]->(c)
  RETURN r1, r2;
  MATCH (a:Element {elementName:  "Argument frame"}),(b:Element {elementName:  "Concern for information privacy"}),(c:Element {elementName: "Post-attitude"})
  CREATE (a)-[r1:RELATES_TO {type: 'moderates' , model: 'Research model'}]->(b)-[r2:RELATES_TO {type: 'moderates', model: 'Research model'}]->(c)
  RETURN r1, r2;
  MATCH (a:Element {elementName: 'Post-attitude'}),(b:Element {elementName: 'Opt-in intention'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Concern for information privacy'}),(b:Element {elementName: 'Opt-in intention'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0002-2021-9443',authorFirst: 'Corey', authorLast: 'Angst', id:"809dbef4-2a03-42d0-8933-bfd52164f7bd"});
  CREATE (:Author {authorFirst: 'Ritu', authorLast: 'Agarwal', id:"958ccbb7-d501-4af1-af47-9fa1a2dc7867"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.2307/20650295'}), (a:Author {id: '809dbef4-2a03-42d0-8933-bfd52164f7bd'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/20650295'}), (a:Author {id: '958ccbb7-d501-4af1-af47-9fa1a2dc7867'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;

  // Create theories referenced in the publication and related them to elements.
  CREATE (:Theory {theoryTitle: 'Elaboration likelihood model'});
  MATCH (t:Theory {theoryTitle: 'Elaboration likelihood model'}), (p:Publication {DOI: '10.2307/20650295'})
  CREATE (p)-[r:DRAWS_ON]->(t)
  RETURN r;
